==> nextcloud-app-tasks-0.9.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/lt_LT.js <==
OC.L10N.register(
    "tasks",
    {
    "Tasks" : "Užduotys",
    "Due yesterday" : "Pasibaigė vakar",
    "Due today" : "pasibaigia šiandien",
    "Due tomorrow" : "Pasibaigs rytoj",
    "Due on" : "Pasibaigs",
    "Started yesterday" : "Pradėta vakar",
    "Starts today" : "prasideda šiandien",
    "Starts tomorrow" : "Prasidės rytoj",
    "Started on" : "Prasidėjo nuo",
    "Starts on" : "Prasideda nuo",
    "[Remind me yesterday at ]HH:mm" : "[Priminti man vakar šiuo laiku]HH:mm",
    "[Remind me today at ]HH:mm" : "[Priminti man šiandien šiuo laiku]HH:mm",
    "[Remind me tomorrow at ]HH:mm" : "[Priminti man rytoj šiuo laiku]HH:mm",
    "[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" : "[Priminti man] YYYY-MMM-DD [šiuo laiku] HH:mm",
    "Yesterday" : "Vakar",
    "Today" : "Šiandien",
    "Tomorrow" : "Rytoj",
    "in %s" : "%s",
    "%s ago" : "prieš %s",
    "seconds" : "sekundžių",
    "a minute" : "min.",
    "%d minutes" : "%d min.",
    "an hour" : "val.",
    "%d hours" : "%d val.",
    "a day" : "diena",
    "%d days" : "%d d.",
    "a month" : "mėnesis",
    "%d months" : "%d mėn.",
    "a year" : "metai",
    "%d years" : "%d metai",
    "week" : "savaitė",
    "weeks" : "savaitės",
    "day" : "diena",
    "days" : "dienos",
    "hour" : "val.",
    "hours" : "valandos",
    "minute" : "minutė",
    "minutes" : "minutės",
    "second" : "antras",
    "before beginning" : "Prieš prasidedant",
    "after beginning" : "po pradžios",
    "before end" : "prieš pabaigą",
    "after end" : "pasibaigus",
    "Comment" : "Komentaras",
    "Add a comment" : "Pridėti komentarą",
    "This will delete the Calendar \"%s\" and all of its entries." : "Tai ištrins kalendorių „%s“ ir visus jo įrašus.",
    "The name \"%s\" is already used." : "Pavadinimas „%s“ jau naudojamas.",
    "An empty name is not allowed." : "Tuščias pavadinimas eilutė neleidžiamas.",
    "Hidden" : "Visada paslėpta",
    "Visible" : "Matoma",
    "Automatic" : "Automatinis",
    "Sunday" : "Sekmadienis",
    "Monday" : "Pirmadienis",
    "Tuesday" : "Antradienis",
    "Wednesday" : "Trečiadienis",
    "Thursday" : "Ketvirtadienis",
    "Friday" : "Penktadienis",
    "Saturday" : "Šeštadienis",
    "Add an important item in \"%s\"..." : "Pridėti svarbų elementą į „%s“...",
    "Add an item due today in \"%s\"..." : "Pridėti elementą atliktiną iki šiandien į „%s“...",
    "Add an item in \"%s\"..." : "Pridėti elementą į „%s“...",
    "Add a current item in \"%s\"..." : "Pridėti dabartinį elementą į „%s“...",
    "Add a subtask to \"%s\"..." : "Pridėti užduotį į \"%s\"...",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n atlikta užduotis","%n atliktos užduotys","%n atliktų užduočių"],
    "Hours" : "Valandos",
    "Minutes" : "Minutės",
    "Set due date" : "Nustatyti atlikimo terminą",
    "%s %% completed" : "%s %% atlikta",
    "priority %s: " : "prioritetas %s: ",
    "high" : "aukštas",
    "medium" : "vidutinis",
    "low" : "žemas",
    "no priority assigned" : "nepriskirtas prioritetas",
    "Remind me" : "Priminti man",
    "at the end" : "pabaigoje",
    "at the beginning" : "Iš pradžių",
    "Set start date" : "Nurodykite pradžios datą",
    "{calendar} shared by {owner}" : "{calendar} pasidalino {owner}",
    "Unnamed" : "Be pavadinimo",
    "Important" : "Svarbūs",
    "Week" : "Savaitė",
    "All" : "Viskas",
    "Current" : "Dabartinis",
    "Completed" : "Atliktas",
    "Delete" : "Ištrinti",
    "Cancel" : "Atsisakyti",
    "Edit" : "Redaguoti",
    "Link" : "Nuoroda",
    "Download" : "Atsisiųsti",
    "Save" : "Įrašyti",
    "Add List..." : "Pridėti sąrašą...",
    "New List" : "Naujas sąrašas",
    "Settings" : "Nustatymai",
    "Start of week" : "Savaitės pradžia",
    "Visibility of Smart Collections" : "Išmanių rinkinių matomumas",
    "Change sort order" : "keisti rikiavimo tvarką",
    "Default" : "Numatytasis",
    "Due date" : "Atlikimo terminas",
    "Start date" : "Pradžios data",
    "Priority" : "Prioritetas",
    "Alphabetically" : "Pagal abėcėlę",
    "Manually" : "Rankiniu būdu",
    "Load remaining completed tasks." : "Įkelti likusias atliktas užduotis.",
    "All day" : "Visą dieną",
    "(New category)" : "(Nauja kategorija)",
    "Select categories..." : "Pasirinkite kategorijas...",
    "Loading the task..." : "Įkeliama užduotis...",
    "Task not found!" : "Užduotis nerasta!",
    "add a subtask to" : "Pridėti užduotį į"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-app-tasks-0.9.6-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/lt_LT.js <==
OC.L10N.register(
    "tasks",
    {
    "Tasks" : "Užduotys",
    "Due yesterday" : "Pasibaigė vakar",
    "Due today" : "Pasibaigia šiandien",
    "Due tomorrow" : "Pasibaigs rytoj",
    "Due on" : "Pasibaigs",
    "Started yesterday" : "Pradėta vakar",
    "Starts today" : "Prasideda šiandien",
    "Starts tomorrow" : "Prasidės rytoj",
    "Started on" : "Prasidėjo nuo",
    "Starts on" : "Prasideda nuo",
    "[Remind me yesterday at ]HH:mm" : "[Priminti man vakar, ties ]HH:mm",
    "[Remind me today at ]HH:mm" : "[Priminti man šiandien, ties ]HH:mm",
    "[Remind me tomorrow at ]HH:mm" : "[Priminti man rytoj, ties ]HH:mm",
    "[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" : "[Priminti man ] YYYY-MMM-DD [ ties ] HH:mm",
    "Yesterday" : "Vakar",
    "Today" : "Šiandien",
    "Tomorrow" : "Rytoj",
    "in %s" : "per %s",
    "%s ago" : "prieš %s",
    "seconds" : "sekundžių",
    "a minute" : "minutė",
    "%d minutes" : "%d minučių",
    "an hour" : "valanda",
    "%d hours" : "%d valandų",
    "a day" : "diena",
    "%d days" : "%d dienų",
    "a month" : "mėnesis",
    "%d months" : "%d mėnesių",
    "a year" : "metai",
    "%d years" : "%d metų",
    "week" : "savaitė",
    "weeks" : "savaitės",
    "day" : "diena",
    "days" : "dienos",
    "hour" : "valanda",
    "hours" : "valandos",
    "minute" : "minutė",
    "minutes" : "minutės",
    "second" : "antras",
    "before beginning" : "prieš prasidedant",
    "after beginning" : "prasidėjus",
    "before end" : "prieš pasibaigiant",
    "after end" : "pasibaigus",
    "Comment" : "Komentaras",
    "Add a comment" : "Pridėti komentarą",
    "This will delete the Calendar \"%s\" and all of its entries." : "Tai ištrins kalendorių „%s“ ir visus jo įrašus.",
    "The name \"%s\" is already used." : "Pavadinimas „%s“ jau naudojamas.",
    "An empty name is not allowed." : "Pavadinimas yra būtinas",
    "Hidden" : "Paslėpta",
    "Visible" : "Matoma",
    "Automatic" : "Automatinis",
    "Sunday" : "Sekmadienis",
    "Monday" : "Pirmadienis",
    "Tuesday" : "Antradienis",
    "Wednesday" : "Trečiadienis",
    "Thursday" : "Ketvirtadienis",
    "Friday" : "Penktadienis",
    "Saturday" : "Šeštadienis",
    "Add an important item in \"%s\"..." : "Pridėti svarbų elementą į „%s“...",
    "Add an item due today in \"%s\"..." : "Pridėti elementą atliktiną iki šiandien į „%s“...",
    "Add an item in \"%s\"..." : "Pridėti elementą į „%s“...",
    "Add a current item in \"%s\"..." : "Pridėti dabartinį elementą į „%s“...",
    "Add a subtask to \"%s\"..." : "Pridėti konkretesnę užduotį į „%s“...",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n atlikta užduotis","%n atliktos užduotys","%n atliktų užduočių"],
    "Hours" : "Valandos",
    "Minutes" : "Minutės",
    "Set due date" : "Nustatyti atlikimo terminą",
    "%s %% completed" : "%s %% atlikta",
    "priority %s: " : "prioritetas %s: ",
    "high" : "aukštas",
    "medium" : "vidutinis",
    "low" : "žemas",
    "no priority assigned" : "nepriskirtas prioritetas",
    "Remind me" : "Priminti man",
    "at the end" : "pabaigoje",
    "at the beginning" : "pradžioje",
    "Set start date" : "Nurodykite pradžios datą",
    "{calendar} shared by {owner}" : "{calendar} pasidalino {owner}",
    "Unnamed" : "Be pavadinimo",
    "Important" : "Svarbus",
    "Week" : "Savaitė",
    "All" : "Visi",
    "Current" : "Dabartinis",
    "Completed" : "Atliktas",
    "Delete" : "Ištrinti",
    "Cancel" : "Atsisakyti",
    "Edit" : "Redaguoti",
    "Link" : "Nuoroda",
    "Download" : "Atsisiųsti",
    "Save" : "Įrašyti",
    "Add List..." : "Pridėti sąrašą...",
    "New List" : "Naujas sąrašas",
    "Settings" : "Nustatymai",
    "Start of week" : "Savaitės pradžia",
    "Visibility of Smart Collections" : "Išmanių rinkinių matomumas",
    "Change sort order" : "Keisti rikiavimo tvarką",
    "Default" : "Numatytasis",
    "Due date" : "Atlikimo terminas",
    "Start date" : "Pradžios data",
    "Priority" : "Prioritetas",
    "Alphabetically" : "Pagal abėcėlę",
    "Manually" : "Rankiniu būdu",
    "Load remaining completed tasks." : "Įkelti likusias atliktas užduotis.",
    "Task is completed" : "Įvykdyta",
    "All day" : "Visą dieną",
    "(New category)" : "(Nauja kategorija)",
    "Select categories..." : "Pasirinkite kategorijas...",
    "Loading the task..." : "Įkeliama užduotis...",
    "Task not found!" : "Užduotis nerasta!",
    "add a subtask to" : "pridėti konkretesnę užduotį į",
    "Toggle subtasks" : "Perjungti dalines užduotis",
    "Toggle completed subtasks" : "Perjungti užbaigtas dalines užduotis"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && (n%100<10 || n%100>=20) ? 1 : 2);");
